@@ -14,6 +14,7 @@
 # under the License.
 
 import argparse
+import colorsys
 import datetime
 import dateutil
 import fcntl
@@ -336,7 +337,11 @@ class App(object):
             self.welcome()
 
         self.loop.screen.tty_signal_keys(start='undefined', stop='undefined')
-        #self.loop.screen.set_terminal_properties(colors=88)
+        if os.environ.get('COLORTERM') == 'truecolor':
+            self.loop.screen.set_terminal_properties(colors=2**24)
+        with self.db.getSession() as session:
+            for label in session.getLabels():
+                self.registerPaletteEntry(label.id, label.color)
 
         self.startSocketListener()
 
@@ -349,6 +354,19 @@ class App(object):
             self.sync.offline = True
             self.status.update(offline=True)
 
+    def registerPaletteEntry(self, label_id, label_color):
+        name = "label_" + str(label_id)
+        color = "#" + str(label_color)
+        # Get the luminance of the color. We convert hex to RGB, then RGB to HLS.
+        r,g,b = tuple(int(label_color[i:i+2], 16) for i in (0, 2, 4))
+        _,l,_ = colorsys.rgb_to_hls(r, g, b)
+        if l > 110:
+            fg = "#111"
+        else:
+            fg = "#eee"
+        default_fg, default_bg = self.config.palette.getPaletteItem('pr-data')
+        self.loop.screen.register_palette_entry(name, default_fg, default_bg, foreground_high=fg, background_high=color)
+
     def getOwnAccountId(self):
         return self.own_account_id
 
