@@ -77,6 +77,7 @@ DEFAULT_PALETTE={
     'check-success': ['light green', ''],
     'check-failure': ['light red', ''],
     'check-pending': ['dark magenta', ''],
+    'state-draft': ['yellow', ''],
     # repository list
     'unreviewed-repository': ['white', ''],
     'subscribed-repository': ['default', ''],
@@ -118,6 +119,15 @@ DEFAULT_PALETTE={
     'focused-line-count-threshold-7': ['dark red,standout', ''],
     'line-count-threshold-8': ['light red', ''],
     'focused-line-count-threshold-8': ['light red,standout', ''],
+    # Markdown
+    'md-strong': ['bold', ''],
+    'md-emphasis': ['italics', ''],
+    'md-heading': ['underline,bold', ''],
+    'md-blockquote': ['light gray', ''],
+    'md-blockcode': ['', 'dark gray'],
+    'md-codespan': ['', 'dark gray'],
+    'md-strikethrough': ['strikethrough', ''],
+    'md-thematicbreak': ['light gray', ''],
     }
 
 # A delta from the default palette
@@ -139,6 +149,11 @@ LIGHT_PALETTE = {
     'pr-message-own-header': ['black,bold', ''],
     'focused-link': ['dark blue,bold', ''],
     'filename': ['dark cyan', ''],
+    # Markdown
+    'md-blockquote': ['dark gray', ''],
+    'md-blockcode': ['', 'light gray'],
+    'md-codespan': ['', 'light gray'],
+    'md-thematicbreak': ['dark gray', ''],
     }
 
 class Palette(object):
@@ -158,3 +173,6 @@ class Palette(object):
         for k,v in self.palette.items():
             ret.append(tuple([k]+v))
         return ret
+
+    def getPaletteItem(self, name):
+        return self.palette.get(name, ['',''])
