@@ -95,6 +95,7 @@ def SearchParser():
                 | in_term
                 | is_term
                 | state_term
+                | draft_term
                 | file_term
                 | path_term
                 | limit_term
@@ -430,6 +431,15 @@ def SearchParser():
         else:
             p[0] = hubtty.db.pull_request_table.c.state == p[2]
 
+    def p_draft_term(p):
+        '''draft_term : OP_DRAFT string'''
+        if p[2] == 'true':
+            p[0] = hubtty.db.pull_request_table.c.draft == True
+        elif p[2] == 'false':
+            p[0] = hubtty.db.pull_request_table.c.draft == False
+        else:
+            p[0] = hubtty.db.pull_request_table.c.state == p[2]
+
     def p_limit_term(p):
         '''limit_term : OP_LIMIT NUMBER'''
         # TODO: Implement this.  The sqlalchemy limit call needs to be
