@@ -21,6 +21,7 @@ import threading
 import json
 import time
 import datetime
+import re
 
 import dateutil.parser
 try:
@@ -44,6 +45,9 @@ TIMEOUT=30
 class OfflineError(Exception):
     pass
 
+class RestrictedError(Exception):
+    pass
+
 class RateLimitError(Exception):
     pass
 
@@ -371,6 +375,7 @@ class SyncRepositoryLabelsTask(Task):
                     self.log.info("Created label %s for repository %s", remote_label['name'], repository.name)
                     repository.createLabel(remote_label['id'], remote_label['name'],
                             remote_label['color'], remote_label['description'])
+                    app.registerPaletteEntry(remote_label['id'], remote_label['color'])
                 else:
                     label.name = remote_label['name']
                     label.color = remote_label['color']
@@ -676,6 +681,7 @@ class SyncPullRequestTask(Task):
                                                   remote_pr['html_url'],
                                                   remote_pr['merged'],
                                                   (remote_pr['mergeable'] or False),
+                                                  remote_pr['draft'],
                                                   )
                 self.log.info("Created new pull request %s in local DB.", pr.pr_id)
                 result = PullRequestAddedEvent(pr)
@@ -694,6 +700,7 @@ class SyncPullRequestTask(Task):
             pr.deletions = remote_pr['deletions']
             pr.merged = remote_pr['merged']
             pr.mergeable = remote_pr.get('mergeable') or False
+            pr.draft = remote_pr['draft']
 
             for label in remote_pr['labels']:
                 l = session.getLabel(label['id'])
@@ -704,13 +711,6 @@ class SyncPullRequestTask(Task):
                 if label.id not in remote_label_ids:
                     pr.removeLabel(label)
 
-            # Delete commits that no longer belong to the pull request
-            remote_commits_sha = [c['sha'] for c in remote_commits]
-            for commit in pr.commits:
-                if commit.sha not in remote_commits_sha:
-                    self.log.info("Deleted commit %s", commit.sha)
-                    session.delete(commit)
-
             repo = gitrepo.get_repo(pr.repository.name, app.config)
             for remote_commit in remote_commits:
                 commit = pr.getCommitBySha(remote_commit['sha'])
@@ -720,9 +720,14 @@ class SyncPullRequestTask(Task):
                 if (not commit) or self.force_fetch:
                     fetches[url].append('+%(ref)s:%(ref)s' % dict(ref=ref))
                 if not commit:
+                    if remote_commit['parents']:
+                        parent_sha = remote_commit['parents'][0]['sha']
+                    else:
+                        parent_sha = None
+
                     commit = pr.createCommit((remote_commit['commit']['message'] or '').replace('\r',''),
                                               remote_commit['sha'],
-                                              remote_commit['parents'][0]['sha'])
+                                              parent_sha)
                     self.log.info("Created new commit %s for pull request %s in local DB.",
                                   commit.key, self.pr_id)
 
@@ -855,6 +860,15 @@ class SyncPullRequestTask(Task):
                         comment.file_key = file_id
                     comment.body = (remote_comment.get('body','') or '').replace('\r','')
 
+            # Delete commits that no longer belong to the pull request
+            # Do it at the end so that we don't inadvertently delete
+            # associated comments or message in the session
+            remote_commits_sha = [c['sha'] for c in remote_commits]
+            for commit in pr.commits:
+                if commit.sha not in remote_commits_sha:
+                    self.log.error("Deleted commit %s", commit.sha)
+                    session.delete(commit)
+
             pr.outdated = False
         for url, refs in fetches.items():
             self.log.debug("Fetching from %s with refs %s", url, refs)
@@ -1260,6 +1274,7 @@ class Sync(object):
     def __init__(self, app, disable_background_sync):
         self.user_agent = 'Hubtty/%s %s' % (hubtty.version.version_info.release_string(),
                                             requests.utils.default_user_agent())
+        self.github_api_version = '2022-11-28'
         self.offline = False
         self.account_id = None
         self.app = app
@@ -1328,6 +1343,11 @@ class Sync(object):
             os.write(pipe, six.b('refresh\n'))
             time.sleep(30)
             return task
+        except RestrictedError as e:
+            task.complete(False)
+            self.queue.complete(task)
+            self.log.warning("Failed to run task %s: %s" % (task, e,))
+            self.app.status.update(error=True, refresh=False)
         except Exception:
             task.complete(False)
             self.queue.complete(task)
@@ -1347,6 +1367,16 @@ class Sync(object):
         self.log.debug('HTTP status code: %d', response.status_code)
         if response.status_code == 503:
             raise OfflineError("Received 503 status code")
+        elif response.status_code == 403:
+            result = re.search(r"the `([\w-]+)` organization has enabled OAuth App access restrictions", response.text)
+            if result:
+                org = result.group(1)
+                error_msg = "The '%s' organization has enabled third-party restrictions and has not yet approved Hubtty. Your review will be submitted again next time Hubtty starts. Create yourself a Personal Access Token to continue using Hubtty with this organization: https://hubtty.readthedocs.io/en/latest/authentication.html" % (org,)
+                self.app.error(error_msg)
+                raise RestrictedError("The '%s' organization has enabled third-party restrictions and has not yet approved hubtty" % (org,))
+            else:
+                raise Exception("Received %s status code: %s"
+                        % (response.status_code, response.text))
         elif response.status_code >= 400:
             raise Exception("Received %s status code: %s"
                             % (response.status_code, response.text))
@@ -1359,7 +1389,8 @@ class Sync(object):
         default_headers = {
                 'Accept': 'application/vnd.github.v3+json',
                 'Accept-Encoding': 'gzip',
-                'User-Agent': self.user_agent
+                'User-Agent': self.user_agent,
+                'X-GitHub-Api-Version': self.github_api_version
                 }
 
         if not response_callback:
@@ -1407,7 +1438,8 @@ class Sync(object):
         default_headers = {
                 'Accept': 'application/vnd.github.v3+json',
                 'Content-Type': 'application/json;charset=UTF-8',
-                'User-Agent': self.user_agent
+                'User-Agent': self.user_agent,
+                'X-GitHub-Api-Version': self.github_api_version
                 }
         if not response_callback:
             response_callback = self.checkResponse
@@ -1433,7 +1465,8 @@ class Sync(object):
         url = self.url(path)
         default_headers = {
                 'Content-Type': 'application/json;charset=UTF-8',
-                'User-Agent': self.user_agent
+                'User-Agent': self.user_agent,
+                'X-GitHub-Api-Version': self.github_api_version
                 }
         if not response_callback:
             response_callback = self.checkResponse
@@ -1450,7 +1483,8 @@ class Sync(object):
         url = self.url(path)
         default_headers = {
                 'Content-Type': 'application/json;charset=UTF-8',
-                'User-Agent': self.user_agent
+                'User-Agent': self.user_agent,
+                'X-GitHub-Api-Version': self.github_api_version
                 }
         if not response_callback:
             response_callback = self.checkResponse
@@ -1467,7 +1501,8 @@ class Sync(object):
         url = self.url(path)
         default_headers = {
                 'Content-Type': 'application/json;charset=UTF-8',
-                'User-Agent': self.user_agent
+                'User-Agent': self.user_agent,
+                'X-GitHub-Api-Version': self.github_api_version
                 }
         if not response_callback:
             response_callback = self.checkResponse
